@@ -118,11 +118,15 @@ class MenuItem(BaseMenuItem):
 
     def __init__(self, url=None, menu_display=None, link_type=URL_NAME, css_classes=None, template=None,
                  badge=None, target=None, dropdown=None, show_caret=True, font_awesome=None, no_hover=False,
-                 placement='bottom-start', url_args=None, url_kwargs=None, attributes=None, **kwargs):
+                 placement='bottom-start', url_args=None, url_kwargs=None, attributes=None,
+                 dropdown_kwargs=None, **kwargs):
         super().__init__(**kwargs)
         self._resolved_url = None
         self.link_type = link_type
-        self._href = self.raw_href(url, url_args, url_kwargs)
+        split_url = url.split(',') if url else [None]
+        if url_args is None and len(split_url) > 1:
+            url_args = split_url[1:]
+        self._href = self.raw_href(split_url[0], url_args, url_kwargs)
         self._attributes = attributes
         self.menu_config = {}
         if url is not None and link_type in self.RESOLVABLE_LINK_TYPES:
@@ -133,7 +137,11 @@ class MenuItem(BaseMenuItem):
                 else:
                     menu_display = self.resolved_url.url_name.capitalize()
             if hasattr(view_class, 'menu_config'):
-                self.menu_config = view_class.menu_config
+                if callable(view_class.menu_config):
+                    self.menu_config: dict = view_class.menu_config()
+                else:
+                    # noinspection PyTypeChecker
+                    self.menu_config: dict = view_class.menu_config
         self.menu_display = MenuItemDisplay(menu_display, font_awesome, css_classes)
         self.kwargs = kwargs
         self.template = template
@@ -142,8 +150,10 @@ class MenuItem(BaseMenuItem):
         self.show_caret = show_caret
 
         if dropdown:
+            if dropdown_kwargs is None:
+                dropdown_kwargs = {}
             self.dropdown = HtmlMenu(template='dropdown',
-                                     no_hover=no_hover, placement=placement).add_items(*dropdown)
+                                     no_hover=no_hover, placement=placement, **dropdown_kwargs).add_items(*dropdown)
         else:
             self.dropdown = None
             self.show_caret = False
@@ -181,19 +191,19 @@ class MenuItem(BaseMenuItem):
 
     @property
     def active(self):
-        if self.menu.active:
-            try:
-                url_name = self.resolved_url.url_name
-                if self.resolved_url.namespace:
-                    url_name = f'{self.resolved_url.namespace}:{url_name}'
-                if url_name == self.menu.active:
+        if self.menu:
+            if self.menu.active:
+                try:
+                    url_name = self.resolved_url.url_name
+                    if self.resolved_url.namespace:
+                        url_name = f'{self.resolved_url.namespace}:{url_name}'
+                    if url_name == self.menu.active:
+                        return True
+                except Resolver404:
+                    return
+            else:
+                if self.link_type in self.RESOLVABLE_LINK_TYPES and self.menu.request.path == self._href:
                     return True
-            except Resolver404:
-                return
-        else:
-            if (self.link_type in self.RESOLVABLE_LINK_TYPES
-                    and self.menu.request.path == self._href):
-                return True
 
     @property
     def badge(self):
@@ -207,6 +217,8 @@ class MenuItem(BaseMenuItem):
             return True
 
     def render(self):
+        if self.template is None:
+            self.template = 'django_menus/single_button.html'
         return render_to_string(self.template, dict(**{'menu_item': self}, **self.kwargs))
 
     def raw_href(self, name_url, url_args, url_kwargs):
@@ -255,8 +267,7 @@ class HtmlMenu:
     }
 
     def __init__(self, request=None, template='base', menu_id=None,
-                 placement=None, no_hover=False, button_defaults=None):
-
+                 placement=None, no_hover=False, button_defaults=None, alignment=None):
         self.menu_items = []
         self.button_defaults = getattr(settings, 'DJANGO_MENUS_BUTTON_DEFAULTS', {})
         if button_defaults is not None:
@@ -267,10 +278,9 @@ class HtmlMenu:
         self.active = None
         self.no_hover = no_hover
         self.placement = placement
-        if menu_id:
-            self.id = menu_id
-        else:
-            self.id = random_string()
+        self.alignment = alignment
+        self.fixed_id = menu_id
+        self.id = None
 
     def visible_items(self):
         return [i for i in self.menu_items if i.visible]
@@ -299,6 +309,10 @@ class HtmlMenu:
                 for i in self.menu_items if i.has_badge]
 
     def render(self):
+        if self.fixed_id:
+            self.id = self.fixed_id
+        else:
+            self.id = random_string()
         extra_menus = ''
         for i in self.menu_items:
             if hasattr(i, 'dropdown') and i.dropdown:
